@@ -30,6 +30,7 @@
 """|UDM| pki X.509 DER certificate handling"""
 
 import base64
+from logging import getLogger
 
 from M2Crypto import X509
 
@@ -37,10 +38,11 @@ import univention.admin
 import univention.admin.localization
 import univention.admin.mapping
 import univention.admin.syntax
-import univention.debug as ud
 from univention.admin.layout import Group, Tab
 
 
+log = getLogger('ADMIN')
+
 translation = univention.admin.localization.translation('univention.admin')
 _ = translation.translate
 
@@ -284,7 +286,7 @@ def load_certificate(user_certificate):
     except (X509.X509Error, AttributeError):
         return {}
 
-    ud.debug(ud.ADMIN, ud.INFO, 'value=%s' % values)
+    log.debug('value=%s', values)
     return values
 
 
