@@ -190,6 +190,7 @@ class object(univention.admin.handlers.simpleLdap):
     }
 
     def open(self):
+        # type: () -> None
         univention.admin.handlers.simpleLdap.open(self)
 
         pathResult, self.default_dn = default_container_for_objects(self.lo, self.position.getDomain())
@@ -205,6 +206,7 @@ class object(univention.admin.handlers.simpleLdap):
         self.save()
 
     def _ldap_pre_create(self):
+        # type: () -> None
         super(object, self)._ldap_pre_create()
         if configRegistry.is_false('directory/manager/child/cn/ou', True) and not self.lo.compare_dn(self.position.getDn(), configRegistry.get('ldap/base')):
             # it is possible to have a basedn with cn=foo
@@ -214,6 +216,7 @@ class object(univention.admin.handlers.simpleLdap):
                 raise univention.admin.uexceptions.invalidChild(_('It is not allowed to create a container/ou as child object of a container/cn.'))
 
     def _ldap_post_create(self):
+        # type: () -> None
         super(object, self)._ldap_post_create()
         changes = []
 
@@ -232,12 +235,14 @@ class object(univention.admin.handlers.simpleLdap):
             self.lo.modify(self.default_dn, changes)
 
     def _ldap_pre_rename(self, newdn):
+        # type: (str) -> None
         super(object, self)._ldap_pre_rename(newdn)
         self.move(newdn)
 
     def _ldap_post_move(self, olddn):
+        # type: (str) -> None
         super(object, self)._ldap_post_move(olddn)
-        settings_module = univention.admin.modules.get('settings/directory')
+        settings_module = univention.admin.modules._get('settings/directory')
         settings_object = univention.admin.objects.get(settings_module, None, self.lo, position='', dn=self.default_dn)
         settings_object.open()
         for attr in ['dns', 'license', 'computers', 'shares', 'groups', 'printers', 'policies', 'dhcp', 'networks', 'users', 'mail']:
@@ -247,6 +252,7 @@ class object(univention.admin.handlers.simpleLdap):
         settings_object.modify()
 
     def _ldap_post_modify(self):
+        # type: () -> None
         super(object, self)._ldap_post_modify()
         changes = []
 
@@ -261,6 +267,7 @@ class object(univention.admin.handlers.simpleLdap):
             self.lo.modify(self.default_dn, changes)
 
     def _ldap_pre_remove(self):
+        # type: () -> None
         super(object, self)._ldap_pre_remove()
         changes = []
 
@@ -274,6 +281,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     @classmethod
     def unmapped_lookup_filter(cls):
+        # type: () -> univention.admin.filter.conjunction
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'organizationalUnit'),
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('objectClass', 'univentionBase')]),
@@ -285,4 +293,5 @@ lookup_filter = object.lookup_filter
 
 
 def identify(dn, attr, canonical=False):
+    # type: (str, univention.admin.handlers._Attributes, bool) -> bool
     return b'organizationalUnit' in attr.get('objectClass', []) and b'univentionBase' not in attr.get('objectClass', [])
