@@ -199,6 +199,22 @@ class object(DNSBase):
                 raise univention.admin.uexceptions.InvalidDNS_Information(_('Reverse zone and IP address are incompatible.'))
         super(object, self).ready()
 
+    @classmethod
+    def rewrite_filter(cls, filter, mapping):
+        if filter.variable == 'ip':
+            filter.variable = 'relativeDomainName'
+            if filter.value:
+                if ':' in filter.value:
+                    raise NotImplementedError('IPv6')
+                else:
+                    subnets = [ipaddress.IPv4Interface(u'%s/%d' % (filter.value, netmask)) for netmask in (24, 16, 8)]
+                    subnets = [s.network.network_address.compressed.replace('.0', '') for s in subnets]
+                filter.transform_to_conjunction(univention.admin.filter.conjunction('|', [
+                    rewrite_rev(expression('ip', filter.value), subnet=subnet) for subnet in subnets
+                ]))
+        else:
+            super(object, cls).rewrite_filter(filter, mapping)
+
     @classmethod
     def lookup_filter_superordinate(cls, filter, superordinate):
         # type: (univention.admin.filter.conjunction, univention.admin.handlers.simpleLdap) -> univention.admin.filter.conjunction
