@@ -36,7 +36,7 @@ import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.handlers.dns.forward_zone
 import univention.admin.localization
-from univention.admin.handlers.dns import ARPA_IP4, ARPA_IP6
+from univention.admin.handlers.dns import DNSBase, is_dns  # noqa: F401
 from univention.admin.layout import Group, Tab
 
 
@@ -95,6 +95,7 @@ layout = [
 
 
 def unmapName(old, encoding=()):
+    # type: (list[bytes], univention.admin.handlers._Encoding) -> list[str]
     items = old[0].decode(*encoding).split(u'.', 2)
     items[0] = items[0][1:]
     items[1] = items[1][1:]
@@ -102,6 +103,7 @@ def unmapName(old, encoding=()):
 
 
 def mapName(old, encoding=()):
+    # type: (list[str], univention.admin.handlers._Encoding) -> bytes
     if len(old) == 1:
         return old[0].encode(*encoding)
     if len(old) == 3 and old[2]:
@@ -110,17 +112,19 @@ def mapName(old, encoding=()):
 
 
 def unmapLocation(old, encoding=()):
-    new = []
-    for i in old:
-        new.append(i.decode(*encoding).split(u' ', 3))
-    return new
+    # type: (list[bytes], univention.admin.handlers._Encoding) -> list[list[str]]
+    return [
+        i.decode(*encoding).split(u' ', 3)
+        for i in old
+    ]
 
 
 def mapLocation(old, encoding=()):
-    new = []
-    for i in old:
-        new.append(u' '.join(i).encode(*encoding))
-    return new
+    # type: (list[list[str]], univention.admin.handlers._Encoding) -> list[bytes]
+    return [
+        u' '.join(i).encode(*encoding)
+        for i in old
+    ]
 
 
 mapping = univention.admin.mapping.mapping()
@@ -129,61 +133,25 @@ mapping.register('location', 'sRVRecord', mapLocation, unmapLocation, encoding='
 mapping.register('zonettl', 'dNSTTL', univention.admin.mapping.mapUNIX_TimeInterval, univention.admin.mapping.unmapUNIX_TimeInterval)
 
 
-class object(univention.admin.handlers.simpleLdap):
+class object(DNSBase):
     module = module
 
-    def _updateZone(self):
-        if self.update_zone:
-            self.superordinate.open()
-            self.superordinate.modify()
-
-    def __init__(self, co, lo, position, dn='', superordinate=None, attributes=[], update_zone=True):
-        self.update_zone = update_zone
-        univention.admin.handlers.simpleLdap.__init__(self, co, lo, position, dn, superordinate, attributes=attributes)
-
-    def _ldap_addlist(self):
-        return super(object, self)._ldap_addlist() + [
-            (self.superordinate.mapping.mapName('zone'), self.superordinate.mapping.mapValue('zone', self.superordinate['zone'])),
-        ]
-
-    def _ldap_post_create(self):
-        super(object, self)._ldap_post_create()
-        self._updateZone()
-
-    def _ldap_post_modify(self):
-        super(object, self)._ldap_post_modify()
-        if self.hasChanged(self.descriptions.keys()):
-            self._updateZone()
-
-    def _ldap_post_remove(self):
-        super(object, self)._ldap_post_remove()
-        self._updateZone()
-
     @classmethod
     def unmapped_lookup_filter(cls):
+        # type: () -> univention.admin.filter.conjunction
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'dNSZone'),
-            univention.admin.filter.conjunction('!', [univention.admin.filter.expression('relativeDomainName', '@')]),
-            univention.admin.filter.conjunction('!', [univention.admin.filter.expression('zoneName', '*.in-addr.arpa', escape=False)]),
-            univention.admin.filter.conjunction('!', [univention.admin.filter.expression('zoneName', '*.ip6.arpa', escape=False)]),
             univention.admin.filter.expression('sRVRecord', '*', escape=False),
         ])
 
-    @classmethod
-    def lookup_filter_superordinate(cls, filter, superordinate):
-        filter.expressions.append(univention.admin.filter.expression('zoneName', superordinate.mapping.mapValueDecoded('zone', superordinate['zone']), escape=True))
-        return filter
-
 
 lookup = object.lookup
 lookup_filter = object.lookup_filter
 
 
 def identify(dn, attr, canonical=False):
-    return all([
-        b'dNSZone' in attr.get('objectClass', []),
-        b'@' not in attr.get('relativeDomainName', []),
-        not attr.get('zoneName', [b'.in-addr.arpa'])[0].decode('ASCII').endswith(ARPA_IP4),
-        not attr.get('zoneName', [b'.ip6.arpa'])[0].decode('ASCII').endswith(ARPA_IP6),
-        attr.get('sRVRecord', []),
-    ])
+    # type: (str, univention.admin.handlers._Attributes, bool) -> bool
+    return bool(
+        attr.get('sRVRecord')
+        and is_dns(attr),
+    )
