@@ -38,7 +38,7 @@ import datetime
 import inspect
 import time
 from logging import getLogger
-from typing import Optional, Sequence, Type, Union  # noqa: F401
+from typing import Sequence, Type, Union  # noqa: F401
 
 import ldap.dn
 import six
@@ -67,18 +67,18 @@ class TypeHint(object):
         # in most cases, the Python type is equivalent to the JSON type
         return self._python_types
 
-    _openapi_type = None  # type: Optional[str]
-    _openapi_format = None  # type: Optional[str]
-    _openapi_regex = None  # type: Optional[str]
-    _openapi_example = None  # type: Optional[str]
-    _openapi_readonly = None  # type: Optional[bool]
-    _openapi_writeonly = None  # type: Optional[bool]
+    _openapi_type = None  # type: str | None
+    _openapi_format = None  # type: str | None
+    _openapi_regex = None  # type: str | None
+    _openapi_example = None  # type: str | None
+    _openapi_readonly = None  # type: bool | None
+    _openapi_writeonly = None  # type: bool | None
     _openapi_nullable = True  # everything which can be removed is nullable
 
     _html_element = None
     _html_input_type = None
 
-    _encoding = None  # type: Optional[str]
+    _encoding = None  # type: str | None
     _minimum = float('-inf')
     _maximum = float('inf')
 
@@ -509,7 +509,7 @@ class ArrayType(TypeHint):
 
 
 class ListType(ArrayType):
-    item_type = None  # type: Optional[Type[TypeHint]] # must be set in subclasses
+    item_type = None  # type: Type[TypeHint] | None # must be set in subclasses
 
     def type_check_subitems(self, value):
         item_type = self.item_type(self.property, self.property_name)
@@ -632,8 +632,8 @@ class DictionaryType(TypeHint):
 
 
 class KeyValueDictionaryType(DictionaryType):
-    key_type = None  # type: Optional[_Types]
-    value_type = None  # type: Optional[_Types]
+    key_type = None  # type: _Types | None
+    value_type = None  # type: _Types | None
 
     def openapi_definition(self):
         definition = super(DictionaryType, self).openapi_definition()
